@@ -1,12 +1,20 @@
-import random
-from ..interfaces import *
-from ..utils import Mod
+from ..interfaces import HomomorphicCryptosystem, Computation
+from ..utils import prime, rand, modinv
 
 from functools import reduce
 from operator import mul
 
 class Paillier (HomomorphicCryptosystem):
 
+    @staticmethod
+    def new (size=1024):
+        p = prime(size)
+        while True:
+            q = prime(size)
+            if p != q:
+                break
+        return Paillier(p=p, q=q)
+
     def __init__ (self, **kwargs):
         self._p = kwargs['p']
         self._q = kwargs['q']
@@ -17,18 +25,19 @@ class Paillier (HomomorphicCryptosystem):
         self._g = self._N + 1
 
         self._lambda = self._phi_N
-        self._mu = Mod(self._N).inv(self._phi_N)
+        self._mu = modinv(self._phi_N, self._N)
 
     def get_modulus (self):
-        return self._N * self._N
+        return self._Nsqr
 
     def encrypt (self, m):
-        r = random.randint(0, self._N)
-        N2 = Mod(self._Nsqr)
-        return N2.exp(self._g, m) * N2.exp(r, self._N) % self._Nsqr
+        r = rand(1, self._N - 1)
+        gm = pow(self._g, m, self._Nsqr)
+        rN = pow(r, self._N, self._Nsqr)
+        return gm * rN % self._Nsqr
 
     def decrypt (self, c):
-        L = (Mod(self._N * self._N).exp(c, self._lambda) - 1) // self._N
+        L = (pow(c, self._lambda, self._Nsqr) - 1) // self._N
         return L * self._mu % self._N
 
 class Sum (Computation):
