@@ -1,18 +1,19 @@
+import random
 from .. import THC
-from ..utils import Prime
+from ..utils import prime
 from ..crypto.trivial import Trivial
 from ..crypto.rsa import RSA
 from ..crypto.paillier import Paillier
 from ..crypto.he1 import HE1
-from ._computations import *
+from ._computations import Product, RandomPolynomial
 
 if __name__ ==  '__main__':
 
     ### Trivial
 
-    p = Prime(512)
-    q = Prime(512)
-    r = Prime(32)
+    p = prime(512)
+    q = prime(512)
+    r = prime(32)
     nums = random.sample(range(2**8), 5)
     rp = RandomPolynomial(5, 2**8)
 
@@ -33,7 +34,7 @@ if __name__ ==  '__main__':
 
     ### RSA
 
-    thc = THC(RSA(p=p, q=q, e=Prime(8)), Product(), r)
+    thc = THC(RSA(p=p, q=q, e=(1<<16)+1), Product(), r)
     print('> Multiplications with RSA:')
     print(' * '.join([str(n) for n in nums]) + ' =', thc.compute(nums))
 
